==> aws-cdk-lib-2.51.1-sources.jar: software/amazon/awscdk/services/opsworks/CfnElasticLoadBalancerAttachmentProps.java <==
package software.amazon.awscdk.services.opsworks;

/**
 * Properties for defining a `CfnElasticLoadBalancerAttachment`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.opsworks.*;
 * CfnElasticLoadBalancerAttachmentProps cfnElasticLoadBalancerAttachmentProps = CfnElasticLoadBalancerAttachmentProps.builder()
 *         .elasticLoadBalancerName("elasticLoadBalancerName")
 *         .layerId("layerId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-11-18T21:59:13.793Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_opsworks.CfnElasticLoadBalancerAttachmentProps")
@software.amazon.jsii.Jsii.Proxy(CfnElasticLoadBalancerAttachmentProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnElasticLoadBalancerAttachmentProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Elastic Load Balancing instance name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getElasticLoadBalancerName();

    /**
     * The AWS OpsWorks layer ID to which the Elastic Load Balancing load balancer is attached.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getLayerId();

    /**
     * @return a {@link Builder} of {@link CfnElasticLoadBalancerAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnElasticLoadBalancerAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnElasticLoadBalancerAttachmentProps> {
        java.lang.String elasticLoadBalancerName;
        java.lang.String layerId;

        /**
         * Sets the value of {@link CfnElasticLoadBalancerAttachmentProps#getElasticLoadBalancerName}
         * @param elasticLoadBalancerName The Elastic Load Balancing instance name. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder elasticLoadBalancerName(java.lang.String elasticLoadBalancerName) {
            this.elasticLoadBalancerName = elasticLoadBalancerName;
            return this;
        }

        /**
         * Sets the value of {@link CfnElasticLoadBalancerAttachmentProps#getLayerId}
         * @param layerId The AWS OpsWorks layer ID to which the Elastic Load Balancing load balancer is attached. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder layerId(java.lang.String layerId) {
            this.layerId = layerId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnElasticLoadBalancerAttachmentProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnElasticLoadBalancerAttachmentProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnElasticLoadBalancerAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnElasticLoadBalancerAttachmentProps {
        private final java.lang.String elasticLoadBalancerName;
        private final java.lang.String layerId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.elasticLoadBalancerName = software.amazon.jsii.Kernel.get(this, "elasticLoadBalancerName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.layerId = software.amazon.jsii.Kernel.get(this, "layerId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.elasticLoadBalancerName = java.util.Objects.requireNonNull(builder.elasticLoadBalancerName, "elasticLoadBalancerName is required");
            this.layerId = java.util.Objects.requireNonNull(builder.layerId, "layerId is required");
        }

        @Override
        public final java.lang.String getElasticLoadBalancerName() {
            return this.elasticLoadBalancerName;
        }

        @Override
        public final java.lang.String getLayerId() {
            return this.layerId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("elasticLoadBalancerName", om.valueToTree(this.getElasticLoadBalancerName()));
            data.set("layerId", om.valueToTree(this.getLayerId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_opsworks.CfnElasticLoadBalancerAttachmentProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnElasticLoadBalancerAttachmentProps.Jsii$Proxy that = (CfnElasticLoadBalancerAttachmentProps.Jsii$Proxy) o;

            if (!elasticLoadBalancerName.equals(that.elasticLoadBalancerName)) return false;
            return this.layerId.equals(that.layerId);
        }

        @Override
        public final int hashCode() {
            int result = this.elasticLoadBalancerName.hashCode();
            result = 31 * result + (this.layerId.hashCode());
            return result;
        }
    }
}

==> aws-cdk-lib-2.130.0-sources.jar: software/amazon/awscdk/services/opsworks/CfnElasticLoadBalancerAttachmentProps.java <==
package software.amazon.awscdk.services.opsworks;

/**
 * Properties for defining a <code>CfnElasticLoadBalancerAttachment</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.opsworks.*;
 * CfnElasticLoadBalancerAttachmentProps cfnElasticLoadBalancerAttachmentProps = CfnElasticLoadBalancerAttachmentProps.builder()
 *         .elasticLoadBalancerName("elasticLoadBalancerName")
 *         .layerId("layerId")
 *         .build();
 * </pre></blockquote>
 * <p>
 * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworks-elasticloadbalancerattachment.html">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworks-elasticloadbalancerattachment.html</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-02-23T02:06:35.613Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_opsworks.CfnElasticLoadBalancerAttachmentProps")
@software.amazon.jsii.Jsii.Proxy(CfnElasticLoadBalancerAttachmentProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnElasticLoadBalancerAttachmentProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Elastic Load Balancing instance name.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworks-elasticloadbalancerattachment.html#cfn-opsworks-elasticloadbalancerattachment-elasticloadbalancername">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworks-elasticloadbalancerattachment.html#cfn-opsworks-elasticloadbalancerattachment-elasticloadbalancername</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getElasticLoadBalancerName();

    /**
     * The AWS OpsWorks layer ID to which the Elastic Load Balancing load balancer is attached.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworks-elasticloadbalancerattachment.html#cfn-opsworks-elasticloadbalancerattachment-layerid">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opsworks-elasticloadbalancerattachment.html#cfn-opsworks-elasticloadbalancerattachment-layerid</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getLayerId();

    /**
     * @return a {@link Builder} of {@link CfnElasticLoadBalancerAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnElasticLoadBalancerAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnElasticLoadBalancerAttachmentProps> {
        java.lang.String elasticLoadBalancerName;
        java.lang.String layerId;

        /**
         * Sets the value of {@link CfnElasticLoadBalancerAttachmentProps#getElasticLoadBalancerName}
         * @param elasticLoadBalancerName The Elastic Load Balancing instance name. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder elasticLoadBalancerName(java.lang.String elasticLoadBalancerName) {
            this.elasticLoadBalancerName = elasticLoadBalancerName;
            return this;
        }

        /**
         * Sets the value of {@link CfnElasticLoadBalancerAttachmentProps#getLayerId}
         * @param layerId The AWS OpsWorks layer ID to which the Elastic Load Balancing load balancer is attached. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder layerId(java.lang.String layerId) {
            this.layerId = layerId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnElasticLoadBalancerAttachmentProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnElasticLoadBalancerAttachmentProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnElasticLoadBalancerAttachmentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnElasticLoadBalancerAttachmentProps {
        private final java.lang.String elasticLoadBalancerName;
        private final java.lang.String layerId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.elasticLoadBalancerName = software.amazon.jsii.Kernel.get(this, "elasticLoadBalancerName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.layerId = software.amazon.jsii.Kernel.get(this, "layerId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.elasticLoadBalancerName = java.util.Objects.requireNonNull(builder.elasticLoadBalancerName, "elasticLoadBalancerName is required");
            this.layerId = java.util.Objects.requireNonNull(builder.layerId, "layerId is required");
        }

        @Override
        public final java.lang.String getElasticLoadBalancerName() {
            return this.elasticLoadBalancerName;
        }

        @Override
        public final java.lang.String getLayerId() {
            return this.layerId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("elasticLoadBalancerName", om.valueToTree(this.getElasticLoadBalancerName()));
            data.set("layerId", om.valueToTree(this.getLayerId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_opsworks.CfnElasticLoadBalancerAttachmentProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnElasticLoadBalancerAttachmentProps.Jsii$Proxy that = (CfnElasticLoadBalancerAttachmentProps.Jsii$Proxy) o;

            if (!elasticLoadBalancerName.equals(that.elasticLoadBalancerName)) return false;
            return this.layerId.equals(that.layerId);
        }

        @Override
        public final int hashCode() {
            int result = this.elasticLoadBalancerName.hashCode();
            result = 31 * result + (this.layerId.hashCode());
            return result;
        }
    }
}
